@@ -3,7 +3,7 @@
  * Zend Framework (http://framework.zend.com/)
  *
  * @link      http://github.com/zendframework/zf2 for the canonical source repository
- * @copyright Copyright (c) 2005-2014 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright Copyright (c) 2005-2015 Zend Technologies USA Inc. (http://www.zend.com)
  * @license   http://framework.zend.com/license/new-bsd New BSD License
  */
 
@@ -35,8 +35,13 @@ class InlineScript extends HeadScript
      * @param  string $type      Script type and/or array of script attributes
      * @return InlineScript
      */
-    public function __invoke($mode = self::FILE, $spec = null, $placement = 'APPEND', array $attrs = array(), $type = 'text/javascript')
-    {
+    public function __invoke(
+        $mode = self::FILE,
+        $spec = null,
+        $placement = 'APPEND',
+        array $attrs = array(),
+        $type = 'text/javascript'
+    ) {
         return parent::__invoke($mode, $spec, $placement, $attrs, $type);
     }
 }
